// FILENAME:	WAR_The_Stand.cs
//
// DESIGNER:      Temujin
//
// BASED ON:      DM_City_on_the_edge and WAR_martian_standoff
//------------------------------------------------------------------------------

$missionName = "WAR_The_Stand";

///////////////////////////////////////////////////////////////////////////////////////////////////
// Lots O' Globals
///////////////////////////////////////////////////////////////////////////////////////////////////
$redKills = 0;
$blueKills = 0;

$redBuildingsDestroyed = 0;
$blueBuildingsDestroyed = 0;

$blueHerc1RespawnTime = 0;
$blueHerc2RespawnTime = 0;
$blueHerc3RespawnTime = 0;
$redHerc1RespawnTime = 0;
$redHerc2RespawnTime = 0;
$redHerc3RespawnTime = 0;

$blueHerc1Path = "MissionGroup/blueHerc1Path";
$blueHerc2Path = "MissionGroup/blueHerc2Path";
$blueHerc3Path = "MissionGroup/blueHerc3Path";
$redHerc1Path = "MissionGroup/redHerc1Path";
$redHerc2Path = "MissionGroup/redHerc2Path";
$redHerc3Path = "MissionGroup/redHerc3Path";

$blueHqDestroyed = false;
$redHqDestroyed = false;

///////////////////////////////////////////////////////////////////////////////////////////////////
// the Game Info tab uses these variables in the rules
///////////////////////////////////////////////////////////////////////////////////////////////////
$respawnDelay = 60;
$respawnDelayNoHq = 300;
$BUILDINGS_TO_DESTROY = 6;

///////////////////////////////////////////////////////////////////////////////////////////////////
// our base defender attributes
//
// The jump from 0.9 to 1.0 is a big one. At skill 1.0 and accuracy 1.0 the AI units will aim 
// first for the weapons, then the legs. A little too much for this mission.
//
///////////////////////////////////////////////////////////////////////////////////////////////////
Pilot BluePilot
{
   id = 28;
   
   name = "Blue Guardian";
   
   skill = 0.95;
   accuracy = 0.95;
   aggressiveness = 1.0;
   activateDist = 750.0;
   deactivateBuff = 300.0;
   targetFreq = 2.0;
   trackFreq = 0.0;
   fireFreq = 0.2;
   LOSFreq = 0.2;
   orderFreq = 2.0;
};

Pilot RedPilot
{
   id = 29;
   
   name = "Red Guardian";
   
   skill = 0.95;
   accuracy = 0.95;
   aggressiveness = 1.0;
   activateDist = 750.0;
   deactivateBuff = 300.0;
   targetFreq = 2.0;
   trackFreq = 0.0;
   fireFreq = 0.2;
   LOSFreq = 0.2;
   orderFreq = 2.0;
};

function initGlobalVars()
{
   $scoringFreeze = false;
   
   %playerCount = playerManager::getPlayerCount();
	// clear all points for the players
   for (%p = 0; %p < %playerCount; %p++)
	{
		%player = playerManager::getPlayerNum(%p);
      %player.numKills = 0;
      %player.buildingsDestroyed = 0;
   }
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Standard info from DM_The_Stand 
/////////////////////////////////////////////////////////////////////////////////////////////

exec("multiplayerStdLib.cs");
exec("DMstdLib.cs");
newObject( cinematicsVol, SimVolume, "cinematic.vol" );

function player::onAdd(%this)
{
   say(%this, 0, *IDMULT_WAR_WELCOME);
   say(%this, 0, "Welcome to WAR_The_Stand!  This map designed by ''|''mJ.  This and other maps are available at http://www6.50megs.com/temujin.  At this site you will also find Temujin's skin collections and training manual.");
}

function setDefaultMissionOptions()
{

   // Keep tracks of hercs near a door
	$HercsAtDoor1 = 0;
	$HercsAtDoor2 = 0; 

	$server::TeamPlay = true;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = true;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = false;

   // what can the server admin choose for available teams
   $server::disableTeamRed = false;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = true;
}

function onMissionStart()
{
      marsSounds();

   initGlobalVars();
   
   order( $blueHerc1, guard, $blueHerc1Path );
   order( $blueHerc2, guard, $blueHerc2Path );
   order( $blueHerc3, guard, $blueHerc3Path );
   order( $redHerc1, guard, $redHerc1Path );
   order( $redHerc2, guard, $redHerc2Path );
   order( $redHerc3, guard, $redHerc3Path );
}

function vehicle::onAdd(%this)
{
   // see if it is a player
   %player = playerManager::vehicleIdToPlayerNum(%this);
   if(%player == 0) 
      return;

   schedule( "setEnemyNavPoint(" @ %this @ ");", 1 );
}

function setEnemyNavPoint( %this )
{
   if( getTeam(%this) == *IDSTR_TEAM_BLUE )
   {
      setNavMarker( "MissionGroup/RedBase/n1", true, %this );
   }
   else
   {
      setNavMarker( "MissionGroup/BlueBase/n1", true, %this );
   }
}

function onMissionLoad(){
   cdAudioCycle("Purge", "Terror", "Watching", "Mechsoul", "Newtech"); 

   // get the original ID for each AI Herc ( for use later when we clone them )
   $blueHerc1 = getObjectId( "MissionGroup/blueHercs/h1" );
   $blueHerc2 = getObjectId( "MissionGroup/blueHercs/h2" );
   $blueHerc3 = getObjectId( "MissionGroup/blueHercs/h3" );
   
   $redHerc1 = getObjectId( "MissionGroup/redHercs/h1" );
   $redHerc2 = getObjectId( "MissionGroup/redHercs/h2" );
   $redHerc3 = getObjectId( "MissionGroup/redHercs/h3" );

   %rules = "<tIDMULT_WAR_GAMETYPE>"      @        
            "<tIDMULT_WAR_MAPNAME>"       @ 
            $missionName                  @  
            "<tIDMULT_WAR_OBJECTIVES_1>"  @
            timeDifference($respawnDelay, 0)       @
            "<tIDMULT_WAR_OBJECTIVES_2>"  @
            timeDifference($respawnDelayNoHq, 0)   @
            "<tIDMULT_WAR_OBJECTIVES_3>"  @
            "<tIDMULT_WAR_OBJECTIVES_4>"  @
            $BUILDINGS_TO_DESTROY         @
            "<tIDMULT_WAR_OBJECTIVES_5>"  @
            "<tIDMULT_WAR_SCORING_1>"     @
            "<tIDMULT_WAR_SCORING_2>"     @
            "<tIDMULT_STD_ITEMS>"         @
            "<tIDMULT_WAR_HQ>"            @
            "<tIDMULT_WAR_GENERATORS>"    @
            "<tIDMULT_WAR_TURRETS>"       @
            "<tIDMULT_WAR_FLAGS>"         @
            "<tIDMULT_WAR_GLOW>"          @
            "<tIDMULT_STD_HEAL>"          @
            "<tIDMULT_STD_RELOAD_1>"      @
            $PadWaitTime                  @
            "<tIDMULT_STD_RELOAD_2>";
   
   setGameInfo(%rules);
}

function vehicle::onDestroyed( %this, %destroyer )
{
   if( getTeam( %this ) == *IDSTR_TEAM_RED )
   {
      $blueKills++;
   }
   else
   {
      $redKills++;
   }

   // award the player a kill ( if the enemy is a different color )
   if( getTeam( %destroyer ) != getTeam( %this ) )
   {
      %player = playerManager::vehicleIdToPlayerNum( %destroyer );
      if(%player != 0)
      {
         %player.numKills++;      
      }
   }
   
   //----------------------------------------------------------------
   // If any of our AI hercs die, give a message and re-clone/drop them
   //----------------------------------------------------------------
   if( %this == $blueHerc1 )
   {
      $blueHercsDestroyed++;
      
      if( $blueHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc1\", " @ %this @ ", -200, -750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc1\", " @ %this @ ", -200, -750, 200);", $respawnDelayNoHq);
      }
   }
   if( %this == $blueHerc2 )
   {
      $blueHercsDestroyed++;

      if( $blueHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc2\", " @ %this @ ", 0, -750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc2\", " @ %this @ ", 0, -750, 200);", $respawnDelayNoHq);
      }
   }
   if( %this == $blueHerc3 )
   {
      $blueHercsDestroyed++;
      
      if( $blueHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc3\", " @ %this @ ", 200, -750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$blueHerc3\", " @ %this @ ", 200, -750, 200);", $respawnDelayNoHq);
      }
   }

   if( %this == $redHerc1 )
   {
      $redHercsDestroyed++;
      
      if( $redHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$redHerc1\", " @ %this @ ", -200, 750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$redHerc1\", " @ %this @ ", -200, 750, 200);", $respawnDelayNoHq);
      }
   }
   if( %this == $redHerc2 )
   {
      $redHercsDestroyed++;
      
      if( $redHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$redHerc2\", " @ %this @ ", 0, 750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$redHerc2\", " @ %this @ ", 0, 750, 200);", $respawnDelayNoHq);
      }
   }
   if( %this == $redHerc3 )
   {
      $redHercsDestroyed++;
      
      if( $redHqDestroyed == false )
      {
         schedule( "trevorsCloneVehicle(\"$redHerc3\", " @ %this @ ", 200, 750, 200);", $respawnDelay);
      }
      else
      {
         schedule( "trevorsCloneVehicle(\"$redHerc3\", " @ %this @ ", 200, 750, 200);", $respawnDelayNoHq);
      }
   }

   // left over from missionStdLib.cs
   vehicle::onDestroyedLog(%this, %destroyer);
   
   // give the death messages...
   %message = getFancyDeathMessage(getHUDName(%this), getHUDName(%destroyer));
   if(%message != "")
   {
      say( 0, 0, %message);
   }

   // rules enforcement
   if(
      (getTeam(%this) == getTeam(%destroyer)) &&
      (%this != %destroyer)
   )
   {
      antiTeamKill(%destroyer);
   }
}

function initScoreBoard()
{
   deleteVariables("$ScoreBoard::PlayerColumn*");
   deleteVariables("$ScoreBoard::TeamColumn*");

	$ScoreBoard::PlayerColumnHeader1 = "Team";
	$ScoreBoard::PlayerColumnHeader2 = "Kills";
	$ScoreBoard::PlayerColumnHeader3 = "Buildings Destroyed";

	$ScoreBoard::PlayerColumnFunction1 = "getTeam2";
	$ScoreBoard::PlayerColumnFunction2 = "getKills";
	$ScoreBoard::PlayerColumnFunction3 = "getBuildingsDestroyed";

   $ScoreBoard::TeamColumnHeader1 = "Structures Remaining";
   $ScoreBoard::TeamColumnHeader2 = "Total Kills";
   $ScoreBoard::TeamColumnFunction1 = "getRemainingStructures";
   $ScoreBoard::TeamColumnFunction2 = "getTeamKills";
 
   serverInitScoreBoard();
}

function getTeam2(%player)
{
   if( getTeam( %player ) == *IDSTR_TEAM_BLUE )
   {
      return *IDMULT_BLUE;
   }
   else
   {
      return *IDMULT_RED;
   }
}

function getKills(%player)
{
   if( %player.numKills != "")
      return %player.numKills;
      
   return "0";
}

function getTeamKills(%team)
{
   if( getTeamNameFromTeamId(%team) == *IDSTR_TEAM_BLUE )
   {
      return $blueKills;
   }
   else
   {
      return $redKills;
   }   
}

function getRemainingStructures(%team)
{
   if( getTeamNameFromTeamId(%team) == *IDSTR_TEAM_BLUE )
   {
      return $BUILDINGS_TO_DESTROY - $blueBuildingsDestroyed;
   }
   else
   {
      return $BUILDINGS_TO_DESTROY - $redBuildingsDestroyed;
   }   
}

function getBuildingsDestroyed(%player)
{
   if( %player.buildingsDestroyed != "")
      return %player.buildingsDestroyed;
   
   return "0";
}

/////////////////////////////////////////////////////////////////////////////////////////////
// This code handles the destruction of the buildings
/////////////////////////////////////////////////////////////////////////////////////////////

function RedGen1::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/RedTur1", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_RED_FL_GEN_DESTROYED;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
}

function RedGen2::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/RedTur2", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_RED_FR_GEN_DESTROYED;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
}

function RedGen3::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();
 
  order( "MissionGroup/RedTur3", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_RED_BL_GEN_DESTROYED;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
}

function RedGen4::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/RedTur4", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_RED_BR_GEN_DESTROYED;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
}

function RedGen5::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/RedTur5", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_RED_CEN_GEN_DESTROYED;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
}

function BlueGen1::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/BlueTur1", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_BLUE_FL_GEN_DESTROYED;
  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    
}

function BlueGen2::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/BlueTur2", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_BLUE_FR_GEN_DESTROYED;
  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    
}

function BlueGen3::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/BlueTur3", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_BLUE_BL_GEN_DESTROYED;
  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    
}

function BlueGen4::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/BlueTur4", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_BLUE_BR_GEN_DESTROYED;
  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    
}

function BlueGen5::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();

  order( "MissionGroup/BlueTur5", shutdown, True );
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_BLUE_CEN_GEN_DESTROYED;
  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    


  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    
}

function RedHQ::structure::onDestroyed( %this, %who )
{
  $redBuildingsDestroyed++;
  checkForWin();
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }

  $redHqDestroyed = true;

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_RED_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "ene_struct_dest.wav");    
  say(IDSTR_TEAM_RED, 1234, %txt, "friend_struct_des.wav");    
  say(0, 1234, "<F5>" @ *IDMULT_WAR_RED_HQ_DESTROYED @ timeDifference($respawnDelayNoHq, 0) @ "." );
}


function BlueHQ::structure::onDestroyed( %this, %who )
{
  $blueBuildingsDestroyed++;
  checkForWin();
  %player = playerManager::vehicleIdToPlayerNum( %who );
  if(%player != 0)
  {
      %player.buildingsDestroyed++;     
  }
  
  $blueHqDestroyed = true;

  %txt = "<F5>" @ getHUDName(%who) @ *IDMULT_WAR_DESTROYED_BLUE_STRUCTURE;
  say(IDSTR_TEAM_BLUE, 1234, %txt, "friend_struct_des.wav");    

  say(IDSTR_TEAM_RED, 1234, %txt, "ene_struct_dest.wav");    
  say(0, 1234, "<F5>" @ *IDMULT_WAR_BLUE_HQ_DESTROYED @ timeDifference($respawnDelayNoHq, 0) @ "." );
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Door Operation - Add On...
/////////////////////////////////////////////////////////////////////////////////////////////

function DoorRed::trigger::onEnter(%this, %vehicleId){
	if($hercsAtDoor1 == 0){
            setposition ( "MissionGroup\\RedDoor", 0, 852, -80 );
	}
	$hercsAtDoor1 = $hercsAtDoor1 + 1;
}

function DoorRed::trigger::onLeave(%this, %vehicleId){
	$hercsAtDoor1 = $hercsAtDoor1 - 1;
	if($hercsAtDoor1 == 0){
            setposition ( "MissionGroup\\RedDoor", 0, 852, 80, 90 );
	}
}

function DoorBlue::trigger::onEnter(%this, %vehicleId){
	if($hercsAtDoor2 == 0){
            setposition ( "MissionGroup\\BlueDoor", 0, -850, -80 );
	}
	$hercsAtDoor2 = $hercsAtDoor2 + 1;
}

function DoorBlue::trigger::onLeave(%this, %vehicleId){
	$hercsAtDoor2 = $hercsAtDoor2 - 1;
	if($hercsAtDoor2 == 0){
            setposition ( "MissionGroup\\BlueDoor", 0, -850, 80, 90 );
		}
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Miscelaneous Code
/////////////////////////////////////////////////////////////////////////////////////////////

function checkForWin()
{
   if( $blueBuildingsDestroyed >= $BUILDINGS_TO_DESTROY )
   {
      fadeEvent( 0, out, 1.5, 1.0, 0, 0 ); 
      schedule( "missionEndConditionMet();", 1.6 );
      
      %txt = "Red team wins!";
      messageBox(0, %txt);
   }
   else if( $redBuildingsDestroyed >= $BUILDINGS_TO_DESTROY )
   {
      fadeEvent( 0, out, 1.5, 1.0, 1.0, 0 ); 
      schedule( "missionEndConditionMet();", 1.6 );
      
      %txt = "Blue team wins!";
      messageBox(0, %txt);
   }   
}
 
function trevorsCloneVehicle(%globalVarName, %old, %x, %y, %z)
{
   %clone = cloneVehicle(%old);
   setPosition(%clone, %x, %y, %z);

   schedule( "deleteObject(" @ %old @ ");", $respawnDealNoHq + 10 );

   schedule( %globalVarName @ " = " @ %clone @ ";", 0);

   addToSet( "MissionGroup", %clone );

   %path = %globalVarName @ "Path";
   schedule( "order( " @ %clone @ ", guard, " @ %path @ " );", 1 );
}
